Class: Maatkit::ShowGrants

Inherits:
Object
  • Object
show all
Defined in:
lib/maatkit-ruby/mk-show-grants.rb

Overview

Canonicalize and print MySQL grants so you can effectively replicate, compare and version-control them.

Maatkit::ShowGrants.new( array, str, array)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize ⇒ ShowGrants

Returns a new ShowGrants Object



46
47
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 46

def initialize()
end

Instance Attribute Details

#ask_pass ⇒ Object

FALSE



15
16
17
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 15

def ask_pass
  @ask_pass
end

#charset ⇒ Object

(No # value)



16
17
18
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 16

def charset
  @charset
end

#config ⇒ Object

/etc/maatkit/maatkit.conf,/etc/maatkit/mk_show_grants.conf,/home/joel/.maatkit.conf,/home/joel/.mk_show_grants.conf



17
18
19
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 17

def config
  @config
end

#database ⇒ Object

(No # value)



18
19
20
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 18

def database
  @database
end

#defaults_file ⇒ Object

(No # value)



19
20
21
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 19

def defaults_file
  @defaults_file
end

#drop ⇒ Object

FALSE



20
21
22
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 20

def drop
  @drop
end

#flush ⇒ Object

FALSE



21
22
23
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 21

def flush
  @flush
end

#header ⇒ Object

TRUE



22
23
24
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 22

def header
  @header
end

#help ⇒ Object

TRUE



23
24
25
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 23

def help
  @help
end

#host ⇒ Object

(No # value)



24
25
26
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 24

def host
  @host
end

#ignore ⇒ Object

(No # value)



25
26
27
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 25

def ignore
  @ignore
end

#only ⇒ Object

(No # value)



26
27
28
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 26

def only
  @only
end

#password ⇒ Object

(No # value)



27
28
29
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 27

def password
  @password
end

#path_to_mk_show_grants ⇒ Object

Sets the executable path, otherwise the environment path will be used.



41
42
43
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 41

def path_to_mk_show_grants
  @path_to_mk_show_grants
end

#pid ⇒ Object

(No # value)



28
29
30
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 28

def pid
  @pid
end

#port ⇒ Object

(No # value)



29
30
31
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 29

def port
  @port
end

#revoke ⇒ Object

FALSE



30
31
32
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 30

def revoke
  @revoke
end

#separate ⇒ Object

FALSE



31
32
33
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 31

def separate
  @separate
end

#set_vars ⇒ Object

wait_timeout=10000



32
33
34
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 32

def set_vars
  @set_vars
end

#socket ⇒ Object

(No # value)



33
34
35
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 33

def socket
  @socket
end

#timestamp ⇒ Object

TRUE



34
35
36
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 34

def timestamp
  @timestamp
end

#user ⇒ Object

(No # value)



35
36
37
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 35

def user
  @user
end

#version ⇒ Object

FALSE



36
37
38
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 36

def version
  @version
end

Instance Method Details

#start(options = nil) ⇒ Object

Execute the command



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/maatkit-ruby/mk-show-grants.rb', line 52

def start(options = nil)
  tmp = Tempfile.new('tmp')
  command = option_string() + options.to_s + " 2> " + tmp.path
  success = system(command)
  if success
    begin
      while (line = tmp.readline)
        line.chomp
        selected_string = line
      end
    rescue EOFError
      tmp.close
    end
    return selected_string
  else
    tmp.close!
    return success
  end
end