Method: Maatkit::ParallelDump#progress
- Defined in:
- lib/maatkit-ruby/mk-parallel-dump.rb
#progress ⇒ Object
Display progress reports. Progress is displayed each time a table or chunk of a table finishes dumping. Progress is calculated by measuring the average data size of each full chunk and assuming all bytes are created equal. The output is the completed and total bytes, the percent completed, estimated time remaining, and estimated completion time. For example:
40.72k/112.00k 36.36% ETA 00:00 (2009-10-27T19:17:53)
If “–chunk-size” is not specified then each table is effectively one big chunk and the progress reports are pretty accurate. When “–chunk-size” is specified the progress reports can be skewed because of averaging. Progress reports are inaccurate when a dump is resumed. This is known issue and will be fixed in a later release.
217 218 219 |
# File 'lib/maatkit-ruby/mk-parallel-dump.rb', line 217 def progress @progress end |